==> knative-model-6.3.1-sources.jar: io/fabric8/knative/eventing/contrib/kafka/v1beta1/KafkaSourceSpecFluent.java <==
package io.fabric8.knative.eventing.contrib.kafka.v1beta1;

import io.fabric8.knative.internal.pkg.apis.duck.v1.Destination;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import io.fabric8.knative.internal.pkg.apis.duck.v1.DestinationFluent;
import java.lang.Integer;
import io.fabric8.knative.internal.pkg.apis.duck.v1.CloudEventOverrides;
import java.lang.Deprecated;
import io.fabric8.knative.internal.pkg.apis.duck.v1.CloudEventOverridesFluent;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface KafkaSourceSpecFluent<A extends KafkaSourceSpecFluent<A>> extends Fluent<A>{
  public A addToBootstrapServers(Integer index,String item);
  public A setToBootstrapServers(Integer index,String item);
  public A addToBootstrapServers(java.lang.String... items);
  public A addAllToBootstrapServers(Collection<String> items);
  public A removeFromBootstrapServers(java.lang.String... items);
  public A removeAllFromBootstrapServers(Collection<String> items);
  public List<String> getBootstrapServers();
  public String getBootstrapServer(Integer index);
  public String getFirstBootstrapServer();
  public String getLastBootstrapServer();
  public String getMatchingBootstrapServer(Predicate<String> predicate);
  public Boolean hasMatchingBootstrapServer(Predicate<String> predicate);
  public A withBootstrapServers(List<String> bootstrapServers);
  public A withBootstrapServers(java.lang.String... bootstrapServers);
  public Boolean hasBootstrapServers();
  
  /**
   * This method has been deprecated, please use method buildCeOverrides instead.
   * @return The buildable object.
   */
  @Deprecated
  public CloudEventOverrides getCeOverrides();
  public CloudEventOverrides buildCeOverrides();
  public A withCeOverrides(CloudEventOverrides ceOverrides);
  public Boolean hasCeOverrides();
  public KafkaSourceSpecFluent.CeOverridesNested<A> withNewCeOverrides();
  public KafkaSourceSpecFluent.CeOverridesNested<A> withNewCeOverridesLike(CloudEventOverrides item);
  public KafkaSourceSpecFluent.CeOverridesNested<A> editCeOverrides();
  public KafkaSourceSpecFluent.CeOverridesNested<A> editOrNewCeOverrides();
  public KafkaSourceSpecFluent.CeOverridesNested<A> editOrNewCeOverridesLike(CloudEventOverrides item);
  public String getConsumerGroup();
  public A withConsumerGroup(String consumerGroup);
  public Boolean hasConsumerGroup();
  public Integer getConsumers();
  public A withConsumers(Integer consumers);
  public Boolean hasConsumers();
  public String getInitialOffset();
  public A withInitialOffset(String initialOffset);
  public Boolean hasInitialOffset();
  
  /**
   * This method has been deprecated, please use method buildNet instead.
   * @return The buildable object.
   */
  @Deprecated
  public KafkaNetSpec getNet();
  public KafkaNetSpec buildNet();
  public A withNet(KafkaNetSpec net);
  public Boolean hasNet();
  public KafkaSourceSpecFluent.NetNested<A> withNewNet();
  public KafkaSourceSpecFluent.NetNested<A> withNewNetLike(KafkaNetSpec item);
  public KafkaSourceSpecFluent.NetNested<A> editNet();
  public KafkaSourceSpecFluent.NetNested<A> editOrNewNet();
  public KafkaSourceSpecFluent.NetNested<A> editOrNewNetLike(KafkaNetSpec item);
  
  /**
   * This method has been deprecated, please use method buildSink instead.
   * @return The buildable object.
   */
  @Deprecated
  public Destination getSink();
  public Destination buildSink();
  public A withSink(Destination sink);
  public Boolean hasSink();
  public KafkaSourceSpecFluent.SinkNested<A> withNewSink();
  public KafkaSourceSpecFluent.SinkNested<A> withNewSinkLike(Destination item);
  public KafkaSourceSpecFluent.SinkNested<A> editSink();
  public KafkaSourceSpecFluent.SinkNested<A> editOrNewSink();
  public KafkaSourceSpecFluent.SinkNested<A> editOrNewSinkLike(Destination item);
  public A addToTopics(Integer index,String item);
  public A setToTopics(Integer index,String item);
  public A addToTopics(java.lang.String... items);
  public A addAllToTopics(Collection<String> items);
  public A removeFromTopics(java.lang.String... items);
  public A removeAllFromTopics(Collection<String> items);
  public List<String> getTopics();
  public String getTopic(Integer index);
  public String getFirstTopic();
  public String getLastTopic();
  public String getMatchingTopic(Predicate<String> predicate);
  public Boolean hasMatchingTopic(Predicate<String> predicate);
  public A withTopics(List<String> topics);
  public A withTopics(java.lang.String... topics);
  public Boolean hasTopics();
  public interface CeOverridesNested<N> extends Nested<N>,CloudEventOverridesFluent<KafkaSourceSpecFluent.CeOverridesNested<N>>{
    public N and();
    public N endCeOverrides();
    
  }
  public interface NetNested<N> extends Nested<N>,KafkaNetSpecFluent<KafkaSourceSpecFluent.NetNested<N>>{
    public N and();
    public N endNet();
    
  }
  public interface SinkNested<N> extends Nested<N>,DestinationFluent<KafkaSourceSpecFluent.SinkNested<N>>{
    public N and();
    public N endSink();
    
  }
  
}

==> knative-model-6.7.1-sources.jar: io/fabric8/knative/eventing/contrib/kafka/v1beta1/KafkaSourceSpecFluent.java <==
package io.fabric8.knative.eventing.contrib.kafka.v1beta1;

import io.fabric8.knative.internal.pkg.apis.duck.v1.Destination;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import io.fabric8.knative.internal.pkg.apis.duck.v1.DestinationFluent;
import java.lang.Integer;
import io.fabric8.knative.internal.pkg.apis.duck.v1.CloudEventOverrides;
import java.lang.Deprecated;
import io.fabric8.knative.internal.pkg.apis.duck.v1.CloudEventOverridesFluent;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface KafkaSourceSpecFluent<A extends KafkaSourceSpecFluent<A>> extends Fluent<A>{
  public A addToBootstrapServers(int index,String item);
  public A setToBootstrapServers(int index,String item);
  public A addToBootstrapServers(java.lang.String... items);
  public A addAllToBootstrapServers(Collection<String> items);
  public A removeFromBootstrapServers(java.lang.String... items);
  public A removeAllFromBootstrapServers(Collection<String> items);
  public List<String> getBootstrapServers();
  public String getBootstrapServer(int index);
  public String getFirstBootstrapServer();
  public String getLastBootstrapServer();
  public String getMatchingBootstrapServer(Predicate<String> predicate);
  public Boolean hasMatchingBootstrapServer(Predicate<String> predicate);
  public A withBootstrapServers(List<String> bootstrapServers);
  public A withBootstrapServers(java.lang.String... bootstrapServers);
  public Boolean hasBootstrapServers();
  
  /**
   * This method has been deprecated, please use method buildCeOverrides instead.
   * @return The buildable object.
   */
  @Deprecated
  public CloudEventOverrides getCeOverrides();
  public CloudEventOverrides buildCeOverrides();
  public A withCeOverrides(CloudEventOverrides ceOverrides);
  public Boolean hasCeOverrides();
  public KafkaSourceSpecFluent.CeOverridesNested<A> withNewCeOverrides();
  public KafkaSourceSpecFluent.CeOverridesNested<A> withNewCeOverridesLike(CloudEventOverrides item);
  public KafkaSourceSpecFluent.CeOverridesNested<A> editCeOverrides();
  public KafkaSourceSpecFluent.CeOverridesNested<A> editOrNewCeOverrides();
  public KafkaSourceSpecFluent.CeOverridesNested<A> editOrNewCeOverridesLike(CloudEventOverrides item);
  public String getConsumerGroup();
  public A withConsumerGroup(String consumerGroup);
  public Boolean hasConsumerGroup();
  public Integer getConsumers();
  public A withConsumers(Integer consumers);
  public Boolean hasConsumers();
  public String getInitialOffset();
  public A withInitialOffset(String initialOffset);
  public Boolean hasInitialOffset();
  
  /**
   * This method has been deprecated, please use method buildNet instead.
   * @return The buildable object.
   */
  @Deprecated
  public KafkaNetSpec getNet();
  public KafkaNetSpec buildNet();
  public A withNet(KafkaNetSpec net);
  public Boolean hasNet();
  public KafkaSourceSpecFluent.NetNested<A> withNewNet();
  public KafkaSourceSpecFluent.NetNested<A> withNewNetLike(KafkaNetSpec item);
  public KafkaSourceSpecFluent.NetNested<A> editNet();
  public KafkaSourceSpecFluent.NetNested<A> editOrNewNet();
  public KafkaSourceSpecFluent.NetNested<A> editOrNewNetLike(KafkaNetSpec item);
  
  /**
   * This method has been deprecated, please use method buildSink instead.
   * @return The buildable object.
   */
  @Deprecated
  public Destination getSink();
  public Destination buildSink();
  public A withSink(Destination sink);
  public Boolean hasSink();
  public KafkaSourceSpecFluent.SinkNested<A> withNewSink();
  public KafkaSourceSpecFluent.SinkNested<A> withNewSinkLike(Destination item);
  public KafkaSourceSpecFluent.SinkNested<A> editSink();
  public KafkaSourceSpecFluent.SinkNested<A> editOrNewSink();
  public KafkaSourceSpecFluent.SinkNested<A> editOrNewSinkLike(Destination item);
  public A addToTopics(int index,String item);
  public A setToTopics(int index,String item);
  public A addToTopics(java.lang.String... items);
  public A addAllToTopics(Collection<String> items);
  public A removeFromTopics(java.lang.String... items);
  public A removeAllFromTopics(Collection<String> items);
  public List<String> getTopics();
  public String getTopic(int index);
  public String getFirstTopic();
  public String getLastTopic();
  public String getMatchingTopic(Predicate<String> predicate);
  public Boolean hasMatchingTopic(Predicate<String> predicate);
  public A withTopics(List<String> topics);
  public A withTopics(java.lang.String... topics);
  public Boolean hasTopics();
  public interface CeOverridesNested<N> extends Nested<N>,CloudEventOverridesFluent<KafkaSourceSpecFluent.CeOverridesNested<N>>{
    public N and();
    public N endCeOverrides();
    
  }
  public interface NetNested<N> extends Nested<N>,KafkaNetSpecFluent<KafkaSourceSpecFluent.NetNested<N>>{
    public N and();
    public N endNet();
    
  }
  public interface SinkNested<N> extends Nested<N>,DestinationFluent<KafkaSourceSpecFluent.SinkNested<N>>{
    public N and();
    public N endSink();
    
  }
  
}
